@@ -38,23 +38,19 @@ function kafka_image {
 
 image "queue-proxy"    "${serving}-queue"
 image "activator"      "${serving}-activator"
-image "activator__kube-rbac-proxy"  "$rbac_proxy"
 image "autoscaler"     "${serving}-autoscaler"
-image "autoscaler__kube-rbac-proxy"  "$rbac_proxy"
 image "autoscaler-hpa" "${serving}-autoscaler-hpa"
-image "autoscaler-hpa__kube-rbac-proxy"  "$rbac_proxy"
 image "controller"     "${serving}-controller"
-image "controller__kube-rbac-proxy"  "$rbac_proxy"
-image "webhook"        "${serving}-webhook"
-image "webhook__kube-rbac-proxy"  "$rbac_proxy"
+image "webhook__webhook" "${serving}-webhook"
 image "domain-mapping" "${serving}-domain-mapping"
-image "domain-mapping__kube-rbac-proxy"  "$rbac_proxy"
 image "domainmapping-webhook" "${serving}-domain-mapping-webhook"
-image "domainmapping-webhook__kube-rbac-proxy"  "$rbac_proxy"
 image "storage-version-migration-serving-serving-$(metadata.get dependencies.serving)__migrate" "${serving}-storage-version-migration"
 
-image "3scale-kourier-gateway" "docker.io/maistra/proxyv2-ubi8:$(metadata.get dependencies.maistra)"
-image "3scale-kourier-control" "${registry}/knative-v$(metadata.get dependencies.kourier):kourier"
+image "kourier-gateway" "docker.io/maistra/proxyv2-ubi8:$(metadata.get dependencies.maistra)"
+image "kourier-control" "${registry}/knative-v$(metadata.get dependencies.kourier):kourier"
+
+image "networking-istio" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-controller"
+image "istio-webhook__webhook" "${registry}/knative-v$(metadata.get dependencies.net_istio):net-istio-webhook"
 
 image "eventing-controller__eventing-controller"    "${eventing}-controller"
 image "sugar-controller__controller"                "${eventing}-sugar-controller"
@@ -78,6 +74,8 @@ kafka_image "DISPATCHER_IMAGE"                     "${eventing_kafka}-consolidat
 kafka_image "kafka-ch-dispatcher__dispatcher"      "${eventing_kafka}-consolidated-dispatcher"
 kafka_image "kafka-webhook__kafka-webhook"         "${eventing_kafka}-webhook"
 
+image "KUBE_RBAC_PROXY"   "${rbac_proxy}"
+
 declare -A yaml_keys
 yaml_keys[spec.version]="$(metadata.get project.version)"
 yaml_keys[metadata.name]="$(metadata.get project.name).v$(metadata.get project.version)"
